summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/browser_instant_controller.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/ui/browser_instant_controller.h')
-rw-r--r--chrome/browser/ui/browser_instant_controller.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/chrome/browser/ui/browser_instant_controller.h b/chrome/browser/ui/browser_instant_controller.h
index e5d6836..21cc6d8 100644
--- a/chrome/browser/ui/browser_instant_controller.h
+++ b/chrome/browser/ui/browser_instant_controller.h
@@ -80,8 +80,9 @@ class BrowserInstantController : public content::NotificationObserver,
// to the user clicking on it.
void InstantOverlayFocused();
- // Invoked by |instant_| to give the omnibox focus invisibly.
- void FocusOmniboxInvisibly();
+ // Invoked by |instant_| to give the omnibox focus, with the option of making
+ // the caret invisible.
+ void FocusOmnibox(bool caret_visibility);
// Invoked by |instant_| to get the currently active tab, over which the
// overlay would be shown.